@@ -18,16 +18,18 @@ extern crate serde_cbor;
 use std::str::FromStr;
 
 use dittolive_ditto::prelude::*;
+use dotenv::dotenv;
 fn main() -> Result<(), Box<dyn std::error::Error>> {
+    dotenv().ok();
     env_logger::init();
     let mut ditto = Ditto::builder()
         .with_temp_dir()
         .with_identity(|ditto_root| {
             // expected by other apps
             let app_id = AppId::from_str("d0e9a40e-9beb-4c90-bb38-769269cbb6fb")?;
-            // We don't want a fully random Development Identity as we need to make sure we
-            // have a specific AppId shared by all peers
-            identity::Development::new(ditto_root, app_id)
+            // We don't want a fully random OfflinePlayground Identity as we
+            // need to make sure we have a specific AppId shared by all peers
+            identity::OfflinePlayground::new(ditto_root, app_id)
         })?
         .with_minimum_log_level(CLogLevel::Info)
         .with_transport_config(|_identity| -> TransportConfig {
