@@ -160,6 +160,7 @@ impl DittoBuilder {
 
         let auth = identity.authenticator();
         let validity_listener = identity.make_listener(transports.clone());
+        let presence_manager_v2 = Arc::new(PresenceManagerV2Context::new());
 
         let sdk_ditto = Ditto {
             ditto,
@@ -170,6 +171,7 @@ impl DittoBuilder {
             transports,
             ditto_root,
             validity_listener,
+            presence_manager_v2,
         };
         Ok(sdk_ditto)
     }
